# S3 Explorer

:construction: **Currently in development** :construction:

## IDEAS

Take a look at [this](docs/ideas.md)

## Licence

![Variants of the GPLv3 logo by José Obed](https://www.gnu.org/graphics/gplv3-rounded-red-180x60.jpg "GPLv3 logo")

s3explorer

Copyright (C) 2025  Bouchet Matéo and Conde Cyril

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
